@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,15 +13,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.bigquery_datatransfer_v1.types import transfer
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-from google.protobuf import wrappers_pb2 as wrappers  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+from google.protobuf import wrappers_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -70,7 +67,7 @@ class DataSourceParameter(proto.Message):
             Parameter display name in the user interface.
         description (str):
             Parameter description.
-        type (~.datatransfer.DataSourceParameter.Type):
+        type_ (google.cloud.bigquery_datatransfer_v1.types.DataSourceParameter.Type):
             Parameter type.
         required (bool):
             Is parameter required.
@@ -81,13 +78,13 @@ class DataSourceParameter(proto.Message):
             parameter validation.
         allowed_values (Sequence[str]):
             All possible values for the parameter.
-        min_value (~.wrappers.DoubleValue):
+        min_value (google.protobuf.wrappers_pb2.DoubleValue):
             For integer and double values specifies
             minimum allowed value.
-        max_value (~.wrappers.DoubleValue):
+        max_value (google.protobuf.wrappers_pb2.DoubleValue):
             For integer and double values specifies
             maxminum allowed value.
-        fields (Sequence[~.datatransfer.DataSourceParameter]):
+        fields (Sequence[google.cloud.bigquery_datatransfer_v1.types.DataSourceParameter]):
             Deprecated. This field has no effect.
         validation_description (str):
             Description of the requirements for this
@@ -116,53 +113,24 @@ class DataSourceParameter(proto.Message):
         RECORD = 5
         PLUS_PAGE = 6
 
-    param_id = proto.Field(proto.STRING, number=1)
-
-    display_name = proto.Field(proto.STRING, number=2)
-
-    description = proto.Field(proto.STRING, number=3)
-
-    type = proto.Field(
-        proto.ENUM,
-        number=4,
-        enum=Type,
-    )
-
-    required = proto.Field(proto.BOOL, number=5)
-
-    repeated = proto.Field(proto.BOOL, number=6)
-
-    validation_regex = proto.Field(proto.STRING, number=7)
-
-    allowed_values = proto.RepeatedField(proto.STRING, number=8)
-
-    min_value = proto.Field(
-        proto.MESSAGE,
-        number=9,
-        message=wrappers.DoubleValue,
-    )
-
-    max_value = proto.Field(
-        proto.MESSAGE,
-        number=10,
-        message=wrappers.DoubleValue,
-    )
-
+    param_id = proto.Field(proto.STRING, number=1,)
+    display_name = proto.Field(proto.STRING, number=2,)
+    description = proto.Field(proto.STRING, number=3,)
+    type_ = proto.Field(proto.ENUM, number=4, enum=Type,)
+    required = proto.Field(proto.BOOL, number=5,)
+    repeated = proto.Field(proto.BOOL, number=6,)
+    validation_regex = proto.Field(proto.STRING, number=7,)
+    allowed_values = proto.RepeatedField(proto.STRING, number=8,)
+    min_value = proto.Field(proto.MESSAGE, number=9, message=wrappers_pb2.DoubleValue,)
+    max_value = proto.Field(proto.MESSAGE, number=10, message=wrappers_pb2.DoubleValue,)
     fields = proto.RepeatedField(
-        proto.MESSAGE,
-        number=11,
-        message="DataSourceParameter",
+        proto.MESSAGE, number=11, message="DataSourceParameter",
     )
-
-    validation_description = proto.Field(proto.STRING, number=12)
-
-    validation_help_url = proto.Field(proto.STRING, number=13)
-
-    immutable = proto.Field(proto.BOOL, number=14)
-
-    recurse = proto.Field(proto.BOOL, number=15)
-
-    deprecated = proto.Field(proto.BOOL, number=20)
+    validation_description = proto.Field(proto.STRING, number=12,)
+    validation_help_url = proto.Field(proto.STRING, number=13,)
+    immutable = proto.Field(proto.BOOL, number=14,)
+    recurse = proto.Field(proto.BOOL, number=15,)
+    deprecated = proto.Field(proto.BOOL, number=20,)
 
 
 class DataSource(proto.Message):
@@ -187,7 +155,7 @@ class DataSource(proto.Message):
             data source to prepare data and ingest them into
             BigQuery, e.g.,
             https://www.googleapis.com/auth/bigquery
-        transfer_type (~.transfer.TransferType):
+        transfer_type (google.cloud.bigquery_datatransfer_v1.types.TransferType):
             Deprecated. This field has no effect.
         supports_multiple_transfers (bool):
             Deprecated. This field has no effect.
@@ -204,14 +172,14 @@ class DataSource(proto.Message):
             Specifies whether the data source supports a user defined
             schedule, or operates on the default schedule. When set to
             ``true``, user can override default schedule.
-        parameters (Sequence[~.datatransfer.DataSourceParameter]):
+        parameters (Sequence[google.cloud.bigquery_datatransfer_v1.types.DataSourceParameter]):
             Data source parameters.
         help_url (str):
             Url for the help document for this data
             source.
-        authorization_type (~.datatransfer.DataSource.AuthorizationType):
+        authorization_type (google.cloud.bigquery_datatransfer_v1.types.DataSource.AuthorizationType):
             Indicates the type of authorization.
-        data_refresh_type (~.datatransfer.DataSource.DataRefreshType):
+        data_refresh_type (google.cloud.bigquery_datatransfer_v1.types.DataSource.DataRefreshType):
             Specifies whether the data source supports
             automatic data refresh for the past few days,
             and how it's supported. For some data sources,
@@ -224,7 +192,7 @@ class DataSource(proto.Message):
         manual_runs_disabled (bool):
             Disables backfilling and manual run
             scheduling for the data source.
-        minimum_schedule_interval (~.duration.Duration):
+        minimum_schedule_interval (google.protobuf.duration_pb2.Duration):
             The minimum interval for scheduler to
             schedule runs.
     """
@@ -242,66 +210,32 @@ class DataSource(proto.Message):
         SLIDING_WINDOW = 1
         CUSTOM_SLIDING_WINDOW = 2
 
-    name = proto.Field(proto.STRING, number=1)
-
-    data_source_id = proto.Field(proto.STRING, number=2)
-
-    display_name = proto.Field(proto.STRING, number=3)
-
-    description = proto.Field(proto.STRING, number=4)
-
-    client_id = proto.Field(proto.STRING, number=5)
-
-    scopes = proto.RepeatedField(proto.STRING, number=6)
-
-    transfer_type = proto.Field(
-        proto.ENUM,
-        number=7,
-        enum=transfer.TransferType,
-    )
-
-    supports_multiple_transfers = proto.Field(proto.BOOL, number=8)
-
-    update_deadline_seconds = proto.Field(proto.INT32, number=9)
-
-    default_schedule = proto.Field(proto.STRING, number=10)
-
-    supports_custom_schedule = proto.Field(proto.BOOL, number=11)
-
+    name = proto.Field(proto.STRING, number=1,)
+    data_source_id = proto.Field(proto.STRING, number=2,)
+    display_name = proto.Field(proto.STRING, number=3,)
+    description = proto.Field(proto.STRING, number=4,)
+    client_id = proto.Field(proto.STRING, number=5,)
+    scopes = proto.RepeatedField(proto.STRING, number=6,)
+    transfer_type = proto.Field(proto.ENUM, number=7, enum=transfer.TransferType,)
+    supports_multiple_transfers = proto.Field(proto.BOOL, number=8,)
+    update_deadline_seconds = proto.Field(proto.INT32, number=9,)
+    default_schedule = proto.Field(proto.STRING, number=10,)
+    supports_custom_schedule = proto.Field(proto.BOOL, number=11,)
     parameters = proto.RepeatedField(
-        proto.MESSAGE,
-        number=12,
-        message=DataSourceParameter,
+        proto.MESSAGE, number=12, message="DataSourceParameter",
     )
-
-    help_url = proto.Field(proto.STRING, number=13)
-
-    authorization_type = proto.Field(
-        proto.ENUM,
-        number=14,
-        enum=AuthorizationType,
-    )
-
-    data_refresh_type = proto.Field(
-        proto.ENUM,
-        number=15,
-        enum=DataRefreshType,
-    )
-
-    default_data_refresh_window_days = proto.Field(proto.INT32, number=16)
-
-    manual_runs_disabled = proto.Field(proto.BOOL, number=17)
-
+    help_url = proto.Field(proto.STRING, number=13,)
+    authorization_type = proto.Field(proto.ENUM, number=14, enum=AuthorizationType,)
+    data_refresh_type = proto.Field(proto.ENUM, number=15, enum=DataRefreshType,)
+    default_data_refresh_window_days = proto.Field(proto.INT32, number=16,)
+    manual_runs_disabled = proto.Field(proto.BOOL, number=17,)
     minimum_schedule_interval = proto.Field(
-        proto.MESSAGE,
-        number=18,
-        message=duration.Duration,
+        proto.MESSAGE, number=18, message=duration_pb2.Duration,
     )
 
 
 class GetDataSourceRequest(proto.Message):
     r"""A request to get data source info.
-
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -310,7 +244,7 @@ class GetDataSourceRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/dataSources/{data_source_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListDataSourcesRequest(proto.Message):
@@ -334,18 +268,15 @@ class ListDataSourcesRequest(proto.Message):
             maximum value of 1000 results.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
 
 
 class ListDataSourcesResponse(proto.Message):
     r"""Returns list of supported data sources and their metadata.
-
     Attributes:
-        data_sources (Sequence[~.datatransfer.DataSource]):
+        data_sources (Sequence[google.cloud.bigquery_datatransfer_v1.types.DataSource]):
             List of supported data sources and their
             transfer settings.
         next_page_token (str):
@@ -359,13 +290,8 @@ class ListDataSourcesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    data_sources = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=DataSource,
-    )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    data_sources = proto.RepeatedField(proto.MESSAGE, number=1, message="DataSource",)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CreateTransferConfigRequest(proto.Message):
@@ -384,7 +310,7 @@ class CreateTransferConfigRequest(proto.Message):
             projects/{project_id}. If specified location and location of
             the destination bigquery dataset do not match - the request
             will fail.
-        transfer_config (~.transfer.TransferConfig):
+        transfer_config (google.cloud.bigquery_datatransfer_v1.types.TransferConfig):
             Required. Data transfer configuration to
             create.
         authorization_code (str):
@@ -423,19 +349,13 @@ class CreateTransferConfigRequest(proto.Message):
             permissions to act as this service account.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     transfer_config = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=transfer.TransferConfig,
+        proto.MESSAGE, number=2, message=transfer.TransferConfig,
     )
-
-    authorization_code = proto.Field(proto.STRING, number=3)
-
-    version_info = proto.Field(proto.STRING, number=5)
-
-    service_account_name = proto.Field(proto.STRING, number=6)
+    authorization_code = proto.Field(proto.STRING, number=3,)
+    version_info = proto.Field(proto.STRING, number=5,)
+    service_account_name = proto.Field(proto.STRING, number=6,)
 
 
 class UpdateTransferConfigRequest(proto.Message):
@@ -444,7 +364,7 @@ class UpdateTransferConfigRequest(proto.Message):
     needs to be provided.
 
     Attributes:
-        transfer_config (~.transfer.TransferConfig):
+        transfer_config (google.cloud.bigquery_datatransfer_v1.types.TransferConfig):
             Required. Data transfer configuration to
             create.
         authorization_code (str):
@@ -467,7 +387,7 @@ class UpdateTransferConfigRequest(proto.Message):
                should be returned in the title bar of the browser, with
                the page text prompting the user to copy the code and
                paste it in the application.
-        update_mask (~.field_mask.FieldMask):
+        update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. Required list of fields to be
             updated in this request.
         version_info (str):
@@ -487,27 +407,18 @@ class UpdateTransferConfigRequest(proto.Message):
     """
 
     transfer_config = proto.Field(
-        proto.MESSAGE,
-        number=1,
-        message=transfer.TransferConfig,
+        proto.MESSAGE, number=1, message=transfer.TransferConfig,
     )
-
-    authorization_code = proto.Field(proto.STRING, number=3)
-
+    authorization_code = proto.Field(proto.STRING, number=3,)
     update_mask = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        message=field_mask.FieldMask,
+        proto.MESSAGE, number=4, message=field_mask_pb2.FieldMask,
     )
-
-    version_info = proto.Field(proto.STRING, number=5)
-
-    service_account_name = proto.Field(proto.STRING, number=6)
+    version_info = proto.Field(proto.STRING, number=5,)
+    service_account_name = proto.Field(proto.STRING, number=6,)
 
 
 class GetTransferConfigRequest(proto.Message):
     r"""A request to get data transfer information.
-
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -516,7 +427,7 @@ class GetTransferConfigRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteTransferConfigRequest(proto.Message):
@@ -531,12 +442,11 @@ class DeleteTransferConfigRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class GetTransferRunRequest(proto.Message):
     r"""A request to get data transfer run information.
-
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -546,12 +456,11 @@ class GetTransferRunRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/runs/{run_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteTransferRunRequest(proto.Message):
     r"""A request to delete data transfer run information.
-
     Attributes:
         name (str):
             Required. The field will contain name of the resource
@@ -561,7 +470,7 @@ class DeleteTransferRunRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}/runs/{run_id}``
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class ListTransferConfigsRequest(proto.Message):
@@ -587,20 +496,16 @@ class ListTransferConfigsRequest(proto.Message):
             maximum value of 1000 results.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    data_source_ids = proto.RepeatedField(proto.STRING, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
+    parent = proto.Field(proto.STRING, number=1,)
+    data_source_ids = proto.RepeatedField(proto.STRING, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
 
 
 class ListTransferConfigsResponse(proto.Message):
     r"""The returned list of pipelines in the project.
-
     Attributes:
-        transfer_configs (Sequence[~.transfer.TransferConfig]):
+        transfer_configs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferConfig]):
             Output only. The stored pipeline transfer
             configurations.
         next_page_token (str):
@@ -615,12 +520,9 @@ class ListTransferConfigsResponse(proto.Message):
         return self
 
     transfer_configs = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=transfer.TransferConfig,
+        proto.MESSAGE, number=1, message=transfer.TransferConfig,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class ListTransferRunsRequest(proto.Message):
@@ -635,7 +537,7 @@ class ListTransferRunsRequest(proto.Message):
             resource name is:
             ``projects/{project_id}/transferConfigs/{config_id}`` or
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}``.
-        states (Sequence[~.transfer.TransferState]):
+        states (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferState]):
             When specified, only transfer runs with
             requested states are returned.
         page_token (str):
@@ -648,7 +550,7 @@ class ListTransferRunsRequest(proto.Message):
         page_size (int):
             Page size. The default page size is the
             maximum value of 1000 results.
-        run_attempt (~.datatransfer.ListTransferRunsRequest.RunAttempt):
+        run_attempt (google.cloud.bigquery_datatransfer_v1.types.ListTransferRunsRequest.RunAttempt):
             Indicates how run attempts are to be pulled.
     """
 
@@ -657,30 +559,17 @@ class ListTransferRunsRequest(proto.Message):
         RUN_ATTEMPT_UNSPECIFIED = 0
         LATEST = 1
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    states = proto.RepeatedField(
-        proto.ENUM,
-        number=2,
-        enum=transfer.TransferState,
-    )
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    page_size = proto.Field(proto.INT32, number=4)
-
-    run_attempt = proto.Field(
-        proto.ENUM,
-        number=5,
-        enum=RunAttempt,
-    )
+    parent = proto.Field(proto.STRING, number=1,)
+    states = proto.RepeatedField(proto.ENUM, number=2, enum=transfer.TransferState,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    page_size = proto.Field(proto.INT32, number=4,)
+    run_attempt = proto.Field(proto.ENUM, number=5, enum=RunAttempt,)
 
 
 class ListTransferRunsResponse(proto.Message):
     r"""The returned list of pipelines in the project.
-
     Attributes:
-        transfer_runs (Sequence[~.transfer.TransferRun]):
+        transfer_runs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferRun]):
             Output only. The stored pipeline transfer
             runs.
         next_page_token (str):
@@ -695,12 +584,9 @@ class ListTransferRunsResponse(proto.Message):
         return self
 
     transfer_runs = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=transfer.TransferRun,
+        proto.MESSAGE, number=1, message=transfer.TransferRun,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class ListTransferLogsRequest(proto.Message):
@@ -723,29 +609,23 @@ class ListTransferLogsRequest(proto.Message):
         page_size (int):
             Page size. The default page size is the
             maximum value of 1000 results.
-        message_types (Sequence[~.transfer.TransferMessage.MessageSeverity]):
+        message_types (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferMessage.MessageSeverity]):
             Message types to return. If not populated -
             INFO, WARNING and ERROR messages are returned.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    page_token = proto.Field(proto.STRING, number=4)
-
-    page_size = proto.Field(proto.INT32, number=5)
-
+    parent = proto.Field(proto.STRING, number=1,)
+    page_token = proto.Field(proto.STRING, number=4,)
+    page_size = proto.Field(proto.INT32, number=5,)
     message_types = proto.RepeatedField(
-        proto.ENUM,
-        number=6,
-        enum=transfer.TransferMessage.MessageSeverity,
+        proto.ENUM, number=6, enum=transfer.TransferMessage.MessageSeverity,
     )
 
 
 class ListTransferLogsResponse(proto.Message):
     r"""The returned list transfer run messages.
-
     Attributes:
-        transfer_messages (Sequence[~.transfer.TransferMessage]):
+        transfer_messages (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferMessage]):
             Output only. The stored pipeline transfer
             messages.
         next_page_token (str):
@@ -760,12 +640,9 @@ class ListTransferLogsResponse(proto.Message):
         return self
 
     transfer_messages = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=transfer.TransferMessage,
+        proto.MESSAGE, number=1, message=transfer.TransferMessage,
     )
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CheckValidCredsRequest(proto.Message):
@@ -784,7 +661,7 @@ class CheckValidCredsRequest(proto.Message):
             ``projects/{project_id}/locations/{location_id}/dataSources/{data_source_id}``.
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class CheckValidCredsResponse(proto.Message):
@@ -796,67 +673,50 @@ class CheckValidCredsResponse(proto.Message):
             If set to ``true``, the credentials exist and are valid.
     """
 
-    has_valid_creds = proto.Field(proto.BOOL, number=1)
+    has_valid_creds = proto.Field(proto.BOOL, number=1,)
 
 
 class ScheduleTransferRunsRequest(proto.Message):
     r"""A request to schedule transfer runs for a time range.
-
     Attributes:
         parent (str):
             Required. Transfer configuration name in the form:
             ``projects/{project_id}/transferConfigs/{config_id}`` or
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}``.
-        start_time (~.timestamp.Timestamp):
+        start_time (google.protobuf.timestamp_pb2.Timestamp):
             Required. Start time of the range of transfer runs. For
             example, ``"2017-05-25T00:00:00+00:00"``.
-        end_time (~.timestamp.Timestamp):
+        end_time (google.protobuf.timestamp_pb2.Timestamp):
             Required. End time of the range of transfer runs. For
             example, ``"2017-05-30T00:00:00+00:00"``.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
-    start_time = proto.Field(
-        proto.MESSAGE,
-        number=2,
-        message=timestamp.Timestamp,
-    )
-
-    end_time = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        message=timestamp.Timestamp,
-    )
+    parent = proto.Field(proto.STRING, number=1,)
+    start_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
 
 
 class ScheduleTransferRunsResponse(proto.Message):
     r"""A response to schedule transfer runs for a time range.
-
     Attributes:
-        runs (Sequence[~.transfer.TransferRun]):
+        runs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferRun]):
             The transfer runs that were scheduled.
     """
 
-    runs = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=transfer.TransferRun,
-    )
+    runs = proto.RepeatedField(proto.MESSAGE, number=1, message=transfer.TransferRun,)
 
 
 class StartManualTransferRunsRequest(proto.Message):
     r"""A request to start manual transfer runs.
-
     Attributes:
         parent (str):
             Transfer configuration name in the form:
             ``projects/{project_id}/transferConfigs/{config_id}`` or
             ``projects/{project_id}/locations/{location_id}/transferConfigs/{config_id}``.
-        requested_time_range (~.datatransfer.StartManualTransferRunsRequest.TimeRange):
+        requested_time_range (google.cloud.bigquery_datatransfer_v1.types.StartManualTransferRunsRequest.TimeRange):
             Time range for the transfer runs that should
             be started.
-        requested_run_time (~.timestamp.Timestamp):
+        requested_run_time (google.protobuf.timestamp_pb2.Timestamp):
             Specific run_time for a transfer run to be started. The
             requested_run_time must not be in the future.
     """
@@ -867,61 +727,44 @@ class StartManualTransferRunsRequest(proto.Message):
         (exclusive).
 
         Attributes:
-            start_time (~.timestamp.Timestamp):
+            start_time (google.protobuf.timestamp_pb2.Timestamp):
                 Start time of the range of transfer runs. For example,
                 ``"2017-05-25T00:00:00+00:00"``. The start_time must be
                 strictly less than the end_time. Creates transfer runs where
-                run_time is in the range betwen start_time (inclusive) and
-                end_time (exlusive).
-            end_time (~.timestamp.Timestamp):
+                run_time is in the range between start_time (inclusive) and
+                end_time (exclusive).
+            end_time (google.protobuf.timestamp_pb2.Timestamp):
                 End time of the range of transfer runs. For example,
                 ``"2017-05-30T00:00:00+00:00"``. The end_time must not be in
                 the future. Creates transfer runs where run_time is in the
-                range betwen start_time (inclusive) and end_time (exlusive).
+                range between start_time (inclusive) and end_time
+                (exclusive).
         """
 
         start_time = proto.Field(
-            proto.MESSAGE,
-            number=1,
-            message=timestamp.Timestamp,
+            proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,
         )
-
         end_time = proto.Field(
-            proto.MESSAGE,
-            number=2,
-            message=timestamp.Timestamp,
+            proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,
         )
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     requested_time_range = proto.Field(
-        proto.MESSAGE,
-        number=3,
-        oneof="time",
-        message=TimeRange,
+        proto.MESSAGE, number=3, oneof="time", message=TimeRange,
     )
-
     requested_run_time = proto.Field(
-        proto.MESSAGE,
-        number=4,
-        oneof="time",
-        message=timestamp.Timestamp,
+        proto.MESSAGE, number=4, oneof="time", message=timestamp_pb2.Timestamp,
     )
 
 
 class StartManualTransferRunsResponse(proto.Message):
     r"""A response to start manual transfer runs.
-
     Attributes:
-        runs (Sequence[~.transfer.TransferRun]):
+        runs (Sequence[google.cloud.bigquery_datatransfer_v1.types.TransferRun]):
             The transfer runs that were created.
     """
 
-    runs = proto.RepeatedField(
-        proto.MESSAGE,
-        number=1,
-        message=transfer.TransferRun,
-    )
+    runs = proto.RepeatedField(proto.MESSAGE, number=1, message=transfer.TransferRun,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
