@@ -21,7 +21,9 @@ def test_shim():
     from google.cloud import bigquery_datatransfer
     from google.cloud import bigquery_datatransfer_v1
 
-    assert bigquery_datatransfer.__all__ == bigquery_datatransfer_v1.__all__
+    assert sorted(bigquery_datatransfer.__all__) == sorted(
+        bigquery_datatransfer_v1.__all__
+    )
 
     for name in bigquery_datatransfer.__all__:
         found = getattr(bigquery_datatransfer, name)
